# VizTyping

<div align='left'>
<img src=https://img.shields.io/badge/docarray-v0.36.0-turquoise.svg >
<img src=https://img.shields.io/badge/jina-v3.19.1-turquoise.svg >
  <img src=https://img.shields.io/badge/vizor-0.0.1-orange.svg >
  <img src=https://img.shields.io/badge/VizNrn-0.0.1-orange.svg >
</div> 

## 简介

> 定义了调度端Vizor和结点VizNrn之间，以及结点之间的通信协议，包括了请求和响应的数据结构定义，以及数据结构的序列化和反序列化方法，
> 所有的结构都是基于[docarray](https://docs.docarray.org/)，
> 这里的所定义的结构可以直接使用[jina](https://github.com/jina-ai/jina)框架的通讯进行http, grpc和websocket进行通讯。



